# Variables and how to organize data

Example code we want to write
```
function some_computation!(vars, eq)
  # get relevant variables
  # and do computation with those (pointwise)
  
  # example
  rho = vars."rho"
  p = vars."p"
  # here we need dotting if p, rho are vectors so that the results 
  # will also be computed inplace and elementwise
  @. p = eq.K * rho^eq.Gamma
  # Dotting also works with begin end environment and also allows to 'escape'
  # some operations. The only issue is that it might not/does not work with
  # functions returning multiple values.
  # Q: Do we need this? Alternatively one can always write a separate
  # for loop instead.
  # A more severe problem is that you cannot use if statements within @.
  # Correction: One can use if statements, but not with values on the current
  # 'node', e.g.
  @. begin
    a = x+1
    if a > 0
      b = x^2
    else
      b = x/2
    end
  end

  # alternative
  # Try to adapt Trixi's approach but with the flexibility of wrapping variables
  # as one likes. For this I would need a function that extracts the desired
  # components only and passes them as an SVector. But then the question about the variable 
  # order comes up again for which Trixi added the 'argument-order-function's that returns a 
  # tuple of names that should be # passed/expected. 
  # IMO this makes things more complicated than it needs to be.

  # why not simply do the following
  for rho, p in zip(vars."rho", vars."p")
    p = eq.K * rho^eq.Gamma
  end
  # but this does not write output inplace ...

  # Q: How does Trixi recognized in what format it should write the values returned
  # as an SVector back into a vector?

  # If I want to have the flexibility of being able to pick into which vectors
  # to write, then I have to stick to for loops anyways, or?
  for i in 1:N
    p[i] = eq.K * rho[i]^eq.Gamma
  end

  # I think the way to go would be to use the @. syntax were possible and
  # later on, if needed, establish something like MathToC for julia (using either SymPy.jl
  # or Symbolics.jl) to make implementing tensorial equations simpler.
end
```

## How to handle variables



These considerations lead me to write the `_VariablesDict` and `_VariablesArray` types,
of which the first one is more developed.
