# High Resolution Shock Capturing & Troubled Cell indicators

## Idea

Separate troubled cell indication (TCI) from high resolution shock capturing (HRSC).
This allows to reuse different TCI strategies with different HRSC approaches.
For this to work we require an interface between TCI and HRSC.
Right now I think the best way to do that is to rely on a single variable, called `indicator`,
that should be computed by a TCI method and later be used by a HRSC method.
We settle on `indicator` being a cellwise defined variable that takes values in `[0,1]`
which should provide a scale to rate how much in need a cell is for an HRSC treatment.

Alternative `indicator` types might be
- of boolean type, e.g. saying that a cell is either troubled or not; would be used by a WENO
implementation,
- defined pointwise, e.g. EntropyProduction is actually defined pointwise; however, the
entropy viscosity paper also includes jumps in the entropy fluxes across cell interfaces for the
in the definition of the artificial viscosity, so perhaps it is not a real alternative.

With regards to HRSC methods, we are implementing the following types of schemes:
- Artificial viscosity (AV): 
  - One set of methods as currently given in the literature, e.g.
Yu, Hesthaven, 2020.
  - Abstract AV: Use the `indicator` variable an one coefficient to compute the needed viscosity.
- Limiting or Reconstruction (yet unsure what it really is):
  - Bernstein reconstruction: Use the `indicator` as a weight for the reconstruction stencile.
  - Gassner/Munz/...: Similar to bernsteining, but use a finite volume (FV) operator as the
  coutner part for the weighting.
- Hybrid methods (not planned yet):
  - SXS and others: Fall back to a standard FD or FV method in case the high order methods fail.

## HRSC

### Methods

We implement the 'legacy' methods available in the literature, e.g.
- Entropy Viscosity,
- Diffusion-based Viscosity,
- Averaged & Highest Modal Decay Viscosity.

Additionally, we role out our Abstract Artificial Viscosity:
Given an TCI variable with values in `[0,1]`, compute the viscosity coefficient.
One can arbitrarily complicate the viscosity computation, but we strive to use the simplest 
approach, e.g. map the indicator linearly to a viscosity. This requires one parameter 
that sets the maximum viscosity. Perhaps it is possible to find an estimate for this coefficient
by looking at aspects of the regularization itself and leaving out the details of the TCI.
Aspects that come to my mind right now:
- Time step width and CFL number: See Kloeckner et al, Yu and Hesthaven about how they 
estimate the time step. E.g. this involves info about the advection speed as well as the
maximum viscosity. Ideally, we don't want the viscosity to dominate the time step width, since
the second order regularization already imposes stringent stepping.
- Perhaps more to find if we test it with different equations.
- Not sure whether a dependence on number of cells or points in cell should be part of this,
or it should be exclusive to the TCI flagging.

## TCI

### Methods

#### Entropy production

Based on Guermond et al., Zingan et al.
Use an entropy inequality to flag cells if the violation of the inequality reaches a certain
threshold. Like all methods, the general formulation requires tuneable constants in order to
make it work properly. For flagging based on entropy production (EP), we would require at
least two constants:
1. a constant to set the scale of EP,
2. a constant to set the maximum EP above which a cell is fully flagged,
3. (optional) a constant for the minimum EP that is tolerable without flagging, because 
numerical errors might cause EP too.

The question is whether all these constants are relevant for a EP TCI to work properly, 
or only a subset of them. In combination with a AV method we would gain another constant
for tuning. Again, here it might be checked whether the AV constant really needs tuning or
if we can fix it by some reasoning.

Assuming the first two coefficients are relevant, what could be heuristics for a scale and
a maximum for EP?

Alternative idea: For the TCI method alone, all we want to have is a value in `[0,1]`.
I think this could be achieved already with only one parameter. E.g.
- Maximum EP: Cutoff everything above it should map to 1. Map the rest linearly onto `[0,1]`.
- Assume a given scale and define the maximum EP to be N units of the scale above zero.
So those two definition are equivalent. Both require a feeling about how much is too much.
This is contrary to the MDA models, where we know from approximation theory which orders
we should expect.

Another difference between MDA and EP is that the latter is an extensive quantity in general.
So any newly designed EP model should account for that by adding in e.g. a grid average
of the entropy.

#### Average & Highest Modal Decay model

Use the smoothness estimation of the approximating polynomial as an indicator, following
work by Kloeckner et al. Although there are one or two parameters for tuning within the
original method, respectively, they might be both associated with the actual AV computation.
The TCI computation itself might be fixed by specifying a lower limit for the
polynomial order under which the cells are flagged. Compared with the EP TCI, there is a 
'natural' scale implied by analytical arguments available.

#### Diffusion

Based on the first AV methods and uses the maximum of the gradient of the fluxes to flag cells.
Again, constants are needed to set a scale and a maximum allowed diffusion.


#### Minmod-ing

This is a binary/boolean indicator that can only see whether a cell is flagged or not.
It works by looking at the vicinity around every point within a cell and check whether it finds
short ranged oscillations.
