# ---
# jupyter:
#   jupytext:
#     formats: ipynb,py:light
#     text_representation:
#       extension: .py
#       format_name: light
#       format_version: '1.5'
#       jupytext_version: 1.13.7
#   kernelspec:
#     display_name: Python 3 (ipykernel)
#     language: python
#     name: python3
# ---

import sympy as sp
import sympy_utils as spu
import gr_utils as gru
import rewrite_utils as rwu

# define parameters
M = sp.symbols(r"M")

# define coordinates
coords = t, r, θ, ϕ = sp.symbols(r"t, r, \theta, \phi")
spu.display_math("(x^i) = ", coords)

# metric
gtt = - (1 - 2 * M / r)
gtr = 2 * M / r
grr = 1 + 2 * M / r
gθθ = r**2
gϕϕ = r**2 * sp.sin(θ)**2
g = sp.Matrix([[ gtt, gtr, 0,     0 ],
               [ gtr, grr, 0,     0 ],
               [ 0,   0,   gθθ, 0 ],
               [ 0,   0,   0,     gϕϕ ]])
display(g)
spu.display_tensor2("g_{{ {}{} }} = ", g, coords, symmetric=True)

# inverse metric
invg = g.inv()
invg = sp.simplify(invg)
display(invg)
spu.display_tensor2("g^{{ {}{} }} = ", invg, coords, symmetric=True)

# ## Hydrodynamics

ρ, h, p, ϵ, Γ, K = sp.symbols(r"\rho h p \epsion \Gamma K")

p = K * ρ**Γ

ϵ = p / ((Γ - 1) * ρ)

h = 1 + ϵ + p / ρ

dhdρ = h.diff(ρ)
dhdρ.simplify()

V2 = (ρ / h * dhdρ).simplify()
display(V2)

varV2 = sp.symbols(r"V^2")
varK = sp.solveset(V2 - varV2, K)
varK

urc, Vc2, rc = sp.symbols(r"u_c^r V_c^2 r_c")
urc = sp.sqrt(M / (2*rc))
Vc2 = urc**2 / (1 - 3*urc**2)
bracket1 = Vc2 - urc**2 / (1 - 2 * M / rc + urc**2); display(bracket1)
bracket2 = 2 * Vc2 - M / (rc * (1 - 2 * M / rc + urc**2)); display(bracket2)

ur = sp.symbols("u_r")
u0 = sp.sqrt(1 - 2 * M / r + ur**2)
u0

du0dur = u0.diff(ur).simplify()
du0dur


