export EulerEq
module EulerEq


using dg1d
using .EquationOfState
using Plots


include("types.jl")
include("equation.jl")
include("rhs.jl")
include("initialdata.jl")
include("plots.jl")
include("callbacks.jl")
include("boundaryconditions.jl")
include("setup.jl")


#######################################################################
#                 dg1d project interface definitions                  #
#######################################################################


dg1d.project_type(::Val{:EulerEq}) = Project

# TODO Remove bdryconds
dg1d.rhs!(env::Environment, P::Project, bdryconds) = rhs!(env, P, P.hrsc, bdryconds...)

dg1d.timestep!(env::Environment, P::Project) = timestep(env, P, P.hrsc)

dg1d.@parameters EulerEq begin

  """
  Initial data configuration. Available options:
  - `smooth_isentropic_flow`
  - `sod_shock_tube`
  - `shu_osher_shock_tube_v1`
  - `shu_osher_shock_tube_v2`
  """
  id = "sine"
  @check id in [ "smooth_isentropic_flow", "sod_shock_tube",
                 "shu_osher_shock_tube_v1", "shu_osher_shock_tube_v2" ]

  """
  Boundary conditions. Available options:
  - `periodic`
  - `from_id`
  """
  bc = "periodic"
  @check bc in [ "periodic", "from_id" ]

end

end # module
