export GRHD
module GRHD


using dg1d
using dg1d.EquationOfState
using Interpolations
using LinearAlgebra
using Plots
using OrderedCollections


include("types.jl")
include("equation.jl")
include("rhs.jl")
include("initialdata.jl")
include("callbacks.jl")
include("plots.jl")
include("boundaryconditions.jl")
include("setup.jl")


#######################################################################
#                 dg1d project interface definitions                  #
#######################################################################


dg1d.project_type(::Val{:GRHD}) = Project

# TODO Remove bdryconds
dg1d.rhs!(env::Environment, P::Project, bdryconds) = rhs!(env, P, P.hrsc, bdryconds...)

dg1d.timestep!(env::Environment, P::Project) = timestep(env, P, P.hrsc)

dg1d.@parameters GRHD begin

  """
  Multiplicative factor to determine restmass density for the artificial atmosphere
  relative to the maximum of restmass density over the grid.
  """
  atm_factor = 1e-10

  """
  Multiplicative factor to determine the cutoff restmass density below which
  we impose artificial atmosphere.
  """
  atm_threshold_factor = 100.0

  """
  Available options:
  - `periodic`
  - `from_initia_data`
  """
  bc = "periodic"

  """
  Available options:
  - `tov`
  - `bondi_accretion`
  - `atmosphere`
  """
  id = "atmosphere"

  """
  Path to an .h5 file containing initial data. Supported initial data types:
  - `tov`
  - `bondi_accretion`
  """
  id_filename = ""

  """
  Restmass density for `atmosphere` initial data.
  """
  id_atmosphere_density = 1e-11

end


end # module
