function make_BoundaryConditions(env, equation, rsolver, prms)
  @unpack bc = prms["GRHD"]
  @unpack cache = env

  broadcast_volume!(scaledcons2cons, equation, cache)

  lhs_bc, rhs_bc = if bc == "periodic"
    PeriodicBC(), PeriodicBC()
  elseif bc == "from_initial_data"
    @unpack sD, sSr, stau = get_dynamic_variables(cache)
    @unpack D, Sr, tau, A, B, r, rho, vr, eps, p = get_static_variables(cache)
    lhs_state = (sD[1], sSr[1], stau[1], p[1], rho[1], vr[1], eps[1],
                 A[1], B[1], r[1])
    rhs_state = (sD[end], sSr[end], stau[end], p[end], rho[end], vr[end], eps[end],
                 A[end], B[end], r[end])
    DirichletBC(lhs_state), DirichletBC(rhs_state)
  else
    error("GRHD: Boundary condition '$type' not implemented!")
  end

  return BoundaryConditions(lhs_bc, rhs_bc, rsolver)
end


function make_BoundaryConditions_LDG(env, equation, ldg_rsolver, prms)

  @unpack bc = prms["GRHD"]

  isnothing(ldg_rsolver) && return nothing

  lhs_bc, rhs_bc = if bc == "periodic"
    PeriodicBC(), PeriodicBC()
  elseif bc == "from_initial_data"
    OutflowBC(), OutflowBC()
  else
    error("GRHD: Boundary condition '$type' not implemented!")
  end

  return BoundaryConditions(lhs_bc, rhs_bc, ldg_rsolver)
end
