module HRSC


using dg1d, LinearAlgebra
import Parameters: @unpack


export AbstractHRSC,
       AbstractArtificialViscosity,
       compute_viscosity!, 
       timestep,
       DBViscosity,
       EntropyViscosity,
       MDAViscosity,
       MDHViscosity,
       AbstractReconstruction,
       BernsteinReconstruction,
       WENOReconstruction


include("interface.jl")
include("ArtificialViscosity.jl")
include("Reconstruction.jl")
# include("Limiter/Limiter.jl")


@parameters HRSC begin

  """
  Available options:
  - `none`      ... disabled
  - `weno`      ... Weighted Non-Oscillatory approximation
  - `av`        ... Artificial viscosity
  - `filter`
  """
  method = "none"
  @check method in [ "weno", "av", "filter" ]

  """
  Available options:
  - `mda`     ... modal decay average
  - `mdh`     ... modal decay based on highest modal coefficient
  - `entropy` ... entropy production
  - `db`      ... diffusion based
  - `tci`     ... viscosity based on TCI monitor
  """
  av_method = "mda"
  @check method in [ "mda", "mdh", "entropy", "db", "tci" ]

  """
  TODO
  """
  av_smoother_order = 1
  @check av_smoother_order in [ 1, 2 ]

  "TODO"
  mda_cmax = 1.0
  @check mda_cmax > 0

  "TODO"
  mdh_cmax = 1.0
  @check mdh_cmax > 0

  "TODO"
  mdh_ca = 0.5
  @check mdh_ca > 0

  "TODO"
  mdh_ck = 0.1
  @check mdh_ck > 0

  "TODO"
  entropy_cmax = 1.0
  @check entropy_cmax > 0

  "TODO"
  entropy_ce = 0.1
  @check entropy_ce > 0

  "TODO"
  db_cmax = 1.0
  @check db_cmax > 0

  "TODO"
  db_cb = 0.5
  @check db_cb > 0

  "TODO"
  tci_threshold = 1e-5
  @check tci_threshold > 0

  "TODO"
  tci_max = 1e-2
  @check tci_max > 0

  "Order of reconstruction polynomial"
  weno_order = 3
  @check weno_order > 0

  """
  Small number to prevent division by zero in WENO weights computation.
  """
  weno_beta = 1e-6
  @check weno_beta > 0

  """
  Available options:
  - `bernstein`
  """
  filter_method = "bernstein"
  @check filter_method in [ "bernstein" ]

end


end
