abstract type AbstractHRSC end


function make_HRSC(mesh, prms)
  @unpack method = prms

  if method == "none"
    return nothing
  elseif method == "weno"
    return WENOReconstruction(mesh, prms["weno_order"], prms["weno_beta"])
  elseif method == "av"
    @unpack av_method, av_smoother_order = prms
    hrsc = if av_method == "mda"
      MDAViscosity(mesh, prms["mda_cmax"])
    elseif av_method == "mdh"
      MDHViscosity(mesh, prms["mdh_cmax"], prms["mdh_ca"], prms["mdh_ck"])
    elseif av_method == "entropy"
      EntropyViscosity(mesh, prms["entropy_cmax"], prms["entropy_ce"])
    elseif av_method == "db"
      DBViscosity(mesh, prms["db_cmax"], prms["db_cb"])
    elseif av_method == "tci"
      TCIViscosity(mesh, prms["tci_threshold"], prms["tci_max"])
    else
      error("HRSC: Unknown method requested: 'av_method = $av_method'")
    end

    if av_smoother_order < 0
      error("HRSC: 'av_smoother_order' must be positive, found $av_smoother_order")
    elseif av_smoother_order > 0
      return SmoothedArtificialViscosity(mesh, hrsc, smoother_order=av_smoother_order)
    else
      return hrsc
    end

  elseif method == "filter"
    @unpack filter_method = prms
    if filter_method == "bernstein"
      return BernsteinReconstruction(mesh)
    else
      error("HRSC: Unknown method requested: 'filter_method = $filter_method'")
    end
  elseif method == "fv-hybrid"
    TODO()
  elseif method == "fd-hybrid"
    TODO()
  else
    error("HRSC: Unknown method requested: '$method'")
  end

end
