module SRHD


using dg1d
using Plots


include("types.jl")
include("equation.jl")
include("rhs.jl")
include("initialdata.jl")
include("callbacks.jl")
include("plots.jl")
include("boundaryconditions.jl")
include("setup.jl")


#######################################################################
#                 dg1d project interface definitions                  #
#######################################################################


dg1d.project_type(::Val{:SRHD}) = Project

# TODO Remove bdryconds
dg1d.rhs!(env::Environment, P::Project, bdryconds) = rhs!(env, P, P.hrsc, bdryconds...)

dg1d.timestep!(env::Environment, P::Project) = timestep(env, P, P.hrsc)

dg1d.@parameters SRHD begin

  """
  Density of artificial atmosphere.
  """
  atm_density = 1e-10
  @check atm_density > 0.0

  """
  Multiplicative factor to determine the cutoff restmass density below which
  we impose artificial atmosphere.
  """
  atm_threshold_factor = 100.0
  @check atm_threshold_factor > 0.0

  """
  Initial data configuration. Available options:
  - `id_smooth`
  - `id_periodic_relativistic_shocktube`
  - `id_periodic_relativistic_shocktube_2`
  - `id_periodic_shocktube_pressure_jump`
  - `id_periodic_shocktube_less_extreme`
  - `id_periodic_sod_shocktube`
  - `id_sod_shocktube`
  """
  id = "sine"
  @check id in [ "id_smooth",
                 "id_periodic_relativistic_shocktube",
                 "id_periodic_relativistic_shocktube_2",
                 "id_periodic_shocktube_pressure_jump",
                 "id_periodic_shocktube_less_extreme",
                 "id_periodic_sod_shocktube",
                 "id_sod_shocktube" ]

  """
  Boundary conditions. Available options:
  - `periodic`
  - `from_id`
  """
  bc = "periodic"
  @check bc in [ "periodic", "from_id" ]

end

end # module
