function make_BoundaryConditions(env, eq, rsolver, prms)

  @unpack mesh = env
  @unpack bc = prms
  @unpack xmin, xmax = mesh

  lhs_bc, rhs_bc = if bc == "periodic"
    PeriodicBC(), PeriodicBC()
  elseif bc == "from_id"
    @unpack D, S, tau = get_dynamic_variables(rhs.cache)
    p0 = 0.0
    DStau_lhs = (D[1], S[1], tau[1])
    (p_lhs,) = find_pressure_insane((DStau_lhs..., p0, xmin), rhs.equation)
    (rho_lhs, v_lhs, eps_lhs) = primitives((DStau_lhs..., p_lhs), rhs.equation)
    lhs_state = (DStau_lhs..., p_lhs, rho_lhs, v_lhs, eps_lhs)
    DStau_rhs = (D[end], S[end], tau[end])
    (p_rhs,) = find_pressure_insane((DStau_rhs..., p0, xmax), rhs.equation)
    (rho_rhs, v_rhs, eps_rhs) = primitives((DStau_rhs..., p_rhs), rhs.equation)
    rhs_state = (DStau_rhs..., p_rhs, rho_rhs, v_rhs, eps_rhs)
    (DirichletBC(lhs_state), DirichletBC(rhs_state))
  else
    error("Unknown boundary condition requested: '$bc'")
  end

  return BoundaryConditions(lhs_bc, rhs_bc, rsolver)
end


function make_BoundaryConditions_LDG(env, eq, ldg_rsolver, prms)

  @unpack bc = prms

  isnothing(ldg_rsolver) && return nothing

  lhs_bc, rhs_bc = if bc == "periodic"
    PeriodicBC(), PeriodicBC()
  elseif bc == "no_inflow"
    OutflowBC(), OutflowBC()
  elseif bc == "from_id"
    OutflowBC(), OutflowBC()
  else
    error("Unknown boundary condition requested: '$bc'")
  end

  return BoundaryConditions(lhs_bc, rhs_bc, ldg_rsolver)
end
