export ScalarEq
module ScalarEq


using dg1d
using Plots


include("types.jl")
include("equation.jl")
include("rhs.jl")
include("initialdata.jl")
include("plots.jl")
include("callbacks.jl")
include("boundaryconditions.jl")
include("setup.jl")


#######################################################################
#                 dg1d project interface definitions                  #
#######################################################################


dg1d.project_type(::Val{:ScalarEq}) = Project

# TODO Remove bdryconds
dg1d.rhs!(env::Environment, P::Project, bdryconds) = rhs!(env, P, P.hrsc, bdryconds...)

dg1d.timestep!(env::Environment, P::Project) = timestep(env, P, P.hrsc)

dg1d.@parameters ScalarEq begin

  """
  Available options:
  - `advection`
  - `burgers`
  """
  equation = "advection"
  @check equation in [ "advection", "burgers" ]

  "Advection speed"
  advection_v = 1.0

  """
  Initial data configuration. Available options:
  - `sine`
  - `bump`
  - `gaussian`
  """
  id = "sine"
  @check id in [ "sine", "bump", "gaussian" ]

  "Period of sine initial data"
  id_sine_period = 1

  "Phase of sine initial data"
  id_sine_phase = 0.0

  "RMS width of gaussian"
  id_gaussian_width = 1.0

  "Amplitude of gaussian"
  id_gaussian_amplitude = 1.0

  """
  Boundary conditions. Available options:
  - `periodic`
  - `no_inflow`
  - `from_id`
  """
  bc = "periodic"
  @check bc in [ "periodic", "no_inflow", "from_id" ]

end


end # ScalarEq
