#######################################################################
#                                Type                                 #
#######################################################################


Base.@kwdef struct EntropyProduction <: AbstractTCI
  mesh::Mesh
  # TODO Rename to max_EP
  EP_max::Float64
end


#######################################################################
#                               Methods                               #
#######################################################################


function compute_indicator!(
    flag, EP, EPjump_lhs, EPjump_rhs, # mutated outputs
    E, Em1, F, Fm1, t, tm1,           # inputs
    tci::EntropyProduction)

  @unpack mesh      = tci
  @unpack invjac, x = mesh
  @unpack D         = mesh.element
  L                 = layout(mesh)
  Npts, K           = L

  E   = reshape(E, L)
  F   = reshape(F, L)
  Em1 = reshape(Em1, L)
  Fm1 = reshape(Fm1, L)
  EP  = reshape(EP, L)
  x   = reshape(x, L)

  # entropy residual
  dt = t - tm1
  dt <= 0 && return # occurs on first time step when no previous entropy is available
  EP .= abs.((E - Em1) / dt + 0.5  * D * (F + Fm1) .* invjac)

  # entropy jumps
  for k = 1:K
    # following index convention of numericalflux.jl
    k_lhs, k_rhs = periodic_index(k-1, K), periodic_index(k, K)
    F_lhs, F_rhs = F[end, k_lhs], F[1,k_rhs]
    EPjump = abs(F_lhs - F_rhs)
    EPjump_lhs[k_rhs], EPjump_rhs[k_lhs] = EPjump, EPjump
  end

  # What parameters can be used?
  # See docs/src/hrsc-tci.md for a discussion
  # One possibility for a scale could be the grid average entropy.
  # avg_E = dg1d.grid_average(E, mesh) # use as scale for indicator
  # @assert !(isapprox(avg_E, 0.0)) "No scale for entropy production available!"

  @unpack EP_max = tci
  for k = 1:K
    cell_EP = maximum( (maximum(EP[:,k]), EPjump_lhs[k], EPjump_rhs[k]) )
    cell_EP = minimum((cell_EP, EP_max))
    flag[k] = cell_EP / EP_max
  end

  return
end
