#######################################################################
#                                Types                                #
#######################################################################


"""
    AbstractTCI

Supertype for TroubledCellIndicator interface.
"""
abstract type AbstractTCI end


#######################################################################
#                              Interface                              #
#######################################################################


#######################################################################
#                               Methods                               #
#######################################################################


function make_TCI(mesh::Mesh, prms)
  @unpack method = prms

  if method == "none"
    return nothing
  elseif method == "mda"
    return ModalDecayAverage(mesh, prms["mda_threshold_min"], prms["mda_threshold_max"])
  elseif method == "mdh"
    return ModalDecayHighest(mesh, prms["mdh_threshold_min"], prms["mdh_threshold_max"])
  elseif method == "diffusion"
    return Diffusion(mesh, prms["diffusion_max"])
  elseif method == "minmod"
    return Minmod(mesh, prms["minmod_threshold"])
  elseif method == "threshold"
    return Threshold(mesh, prms["threshold"])
  elseif method == "entropy_production"
    return EntropyProduction(mesh, prms["entropy_production_max"])
  else
    error("TCI: Unknown method requested: '$method'")
  end

end
