@testset "Parameters" begin

  # a working example
  dg1d.@parameters MyType begin
    "some parameter"
    x = 1.0
    @check x > 0.0
    @check x > 0.5

    "another parameter"
    y = "sers"

    "and another parameter"
    z = 123
  end
  prms = dg1d.parameters(:MyType)
  @test prms["x"] == 1.0
  @test prms["y"] == "sers"
  @test prms["z"] == 123

  # verify check functionality
  dg1d.check_parameters(:MyType, prms)
  # trigger first check
  prms["x"] = 0.2
  @test_throws ErrorException dg1d.check_parameters(:MyType, prms)
  # trigger second check
  prms["x"] = -1.0
  @test_throws ErrorException dg1d.check_parameters(:MyType, prms)

  # test wrong usage

  # missing docstring
  @test_throws LoadError @eval dg1d.@parameters MyType begin
    x = 1.0
  end

  # missing default value
  @test_throws LoadError @eval dg1d.@parameters MyType begin
    "some parameter"
    x
  end

  # duplicated parameter
  @test_throws LoadError @eval dg1d.@parameters MyType begin
    "some parameter"
    x = 1.0
    "same parameter again"
    x = 2.0
  end

  # duplicated parameter
  @test_throws LoadError @eval dg1d.@parameters MyType begin
    "some parameter"
    x = 1.0
    "same parameter again"
    x = 2.0
  end

  # checks can't appear at the start
  @test_throws LoadError @eval dg1d.@parameters MyType begin
    @check x > 0.0
    "some parameter"
    x = 1.0
    "same parameter again"
    x = 2.0
  end

  # no other macros or expressions allowed
  @test_throws LoadError @eval dg1d.@parameters MyType begin
    "some parameter"
    x = 1.0
    @test x > 0.0 # should be @check
    "same parameter again"
    x = 2.0
  end
  @test_throws LoadError @eval dg1d.@parameters MyType begin
    "some parameter"
    x = 1.0
    x > 2.0 # forgot to add @check
    "same parameter again"
    x = 2.0
  end


end
